```puml
@startuml
component "{{ project_name }}" [[{{ project_name }}/{{ project_name }} {{ project_name }}]]{
    
}
@enduml

' for linking: "{{ component_name }}" [[{{ project_name }}/.../{{ component_name }}/{{ component_name }} {{ component_name }}]]
```